@@ -102,7 +102,8 @@ static Bool LoadPYBaseDict(void)
     fc.freqOrder = AD_NO;
 
     FILE *fp;
-    int i, j, iLen;
+    int i, j;
+    uint iLen;
 
     fp = fopen(PY_BASE_FILE, "r");
     if (!fp)
@@ -121,9 +122,9 @@ static Bool LoadPYBaseDict(void)
             fread(&len, sizeof(INT8), 1, fp);
             fread(PYFAList[i].pyBase[j].strHZ, sizeof(char) * len, 1, fp);
             PYFAList[i].pyBase[j].strHZ[len] = '\0';
-            fread(&iLen, sizeof(int), 1, fp);
+            fread(&iLen, sizeof(uint), 1, fp);
             PYFAList[i].pyBase[j].iIndex = iLen;
-            PYFAList[i].pyBase[j].iHit = 0;
+            PYFAList[i].pyBase[j].iHit = iLen;
             PYFAList[i].pyBase[j].flag = 0;
             if (iLen > iCounter)
                 iCounter = iLen;
@@ -146,7 +147,8 @@ static Bool LoadPYBaseDict(void)
 }
 static void LoadPYPhraseDict(FILE *fp, Bool isSystem)
 {
-    int i, j ,k, count, iLen;
+    int i, j ,k, count;
+    uint iLen;
     char strBase[UTF8_MAX_LENGTH + 1];
     PyPhrase *temp, *phrase;
     while (!feof(fp)) {
@@ -187,7 +189,7 @@ static void LoadPYPhraseDict(FILE *fp, Bool isSystem)
             phrase->strPhrase = (char *) malloc(sizeof(char) * (iLen + 1));
             fread(phrase->strPhrase, sizeof(char) * iLen, 1, fp);
             phrase->strPhrase[iLen] = '\0';
-            fread(&iLen, sizeof(unsigned int), 1, fp);
+            fread(&iLen, sizeof(uint), 1, fp);
             phrase->iIndex = iLen;
             if (iLen > iCounter)
                 iCounter = iLen;
